@@ -32,9 +32,10 @@ class AccessType(enum.Enum):
     OCI_REGISTRY = 'ociRegistry'
     GITHUB = 'github'
     HTTP = 'http'
+    LOCAL_OCI_BLOB = 'localOciBlob'
+    LOCAL_FILESYSTEM_BLOB = 'localFilesystemBlob'
     NONE = 'None'  # the resource is only declared informally (e.g. generic)
 
-
 class SourceType(enum.Enum):
     GIT = 'git'
 
@@ -42,7 +43,8 @@ class SourceType(enum.Enum):
 class ResourceType(enum.Enum):
     OCI_IMAGE = 'ociImage'
     GENERIC = 'generic'
-
+    BLUEPRINT = 'blueprint'
+    HELM = 'helm'
 
 class ResourceRelation(enum.Enum):
     LOCAL = 'local'
@@ -51,7 +53,7 @@ class ResourceRelation(enum.Enum):
 
 @dc(frozen=True)
 class ResourceAccess:
-    type: AccessType
+    type: typing.Union[AccessType, str]
 
 
 @dc(frozen=True)
@@ -63,7 +65,6 @@ class OciAccess(ResourceAccess):
 class GithubAccess(ResourceAccess):
     repoUrl: str
     ref: str
-    type: AccessType
     commit: typing.Optional[str] = None
 
     def __post_init__(self):
@@ -103,6 +104,15 @@ class GithubAccess(ResourceAccess):
 class HttpAccess(ResourceAccess):
     url: str
 
+@dc(frozen=True)
+class LocalOCIBlobAccess(ResourceAccess):
+    digest: str
+
+@dc(frozen=True)
+class LocalFilesystemBlobAccess(ResourceAccess):
+    filename: str
+    mediaType: typing.Optional[str] = None
+
 
 @dc(frozen=True)
 class Label:
@@ -284,13 +294,15 @@ class SourceReference(FindLabelMixin):
 class Resource(Artifact, FindLabelMixin):
     name: str
     version: str
-    type: ResourceType
+    type: typing.Union[ResourceType, str]
     access: typing.Union[
         OciAccess,
         GithubAccess,
         HttpAccess,
-        ResourceAccess,
-        None
+        LocalOCIBlobAccess,
+        LocalFilesystemBlobAccess,
+        dict,
+        None,
     ]
     extraIdentity: typing.Dict[str, str] = dataclasses.field(default_factory=dict)
     relation: ResourceRelation = ResourceRelation.LOCAL
@@ -343,6 +355,13 @@ def _read_schema_file(schema_file_path: str):
         return yaml.safe_load(f)
 
 
+def enum_or_string(v, enum_type: enum.Enum):
+  try:
+    return enum_type(v)
+  except ValueError:
+    return str(v)
+
+
 @dc
 class ComponentDescriptor:
     meta: Metadata
@@ -389,7 +408,11 @@ class ComponentDescriptor:
                     SchemaVersion,
                     SourceType,
                     ResourceRelation,
-                ]
+                ],
+                type_hooks={
+                    typing.Union[AccessType, str]: functools.partial(enum_or_string, enum_type=AccessType),
+                    typing.Union[ResourceType, str]: functools.partial(enum_or_string, enum_type=ResourceType),
+                },
             )
         )
         if not validation_mode is ValidationMode.NONE:
